@@ -37,6 +37,11 @@ import numpy as np
 from ase.data import atomic_numbers, chemical_symbols
 
 from runnerase.utils import reader, writer
+from runnerase.plot import (RunnerSplitTrainTestPlots,
+                            RunnerSymmetryFunctionValuesPlots,
+                            RunnerStructureSymmetryFunctionValuesPlots,
+                            RunnerFitResultsPlots,
+                            RunnerScalingPlots)
 
 
 class ElementStorageMixin:
@@ -210,6 +215,11 @@ class RunnerScaling(ElementStorageMixin):
         # The last line contains the minimum and maximum of the target property.
         outfile.write(f'{self.target_min:18.9f} {self.target_max:18.9f}\n')
 
+    @property
+    def plot(self) -> RunnerScalingPlots:
+        """Create a plotting interface."""
+        return RunnerScalingPlots(self.data)
+
 
 class RunnerWeights(ElementStorageMixin):
     """Storage container for RuNNer neural network weights and bias values.
@@ -420,6 +430,11 @@ class RunnerStructureSymmetryFunctionValues(ElementStorageMixin):
 
         return [x for _, x in sorted(zip(index, data_tuples))]
 
+    @property
+    def plot(self) -> RunnerStructureSymmetryFunctionValuesPlots:
+        """Create a plotting interface."""
+        return RunnerStructureSymmetryFunctionValuesPlots(self.data)
+
 
 class RunnerSymmetryFunctionValues:
     """Storage container for RuNNer symmetry function values.
@@ -557,6 +572,11 @@ class RunnerSymmetryFunctionValues:
                           + f'{image.energy_short:{fmt}} '
                           + f'{image.energy_elec:{fmt}}\n')
 
+    @property
+    def plot(self) -> RunnerSymmetryFunctionValuesPlots:
+        """Create a plotting interface."""
+        return RunnerSymmetryFunctionValuesPlots(self.data)
+
 
 class RunnerFitResults:
     """Storage container for RuNNer training results.
@@ -668,6 +688,63 @@ class RunnerFitResults:
             if 'No improvement' in line:
                 self.opt_rmse_epoch = None
 
+    # Table returns many different pieces of information, therefore many
+    # variables are needed.
+    # pylint: disable=too-many-locals
+    def table(self) -> None:
+        """Print a tabular summary of the fitting results."""
+        # Get the results of the fit.
+        energy_train = self.rmse_energy['train']
+        energy_test = self.rmse_energy['test']
+        force_train = self.rmse_forces['train']
+        force_test = self.rmse_forces['test']
+        unit_energy = self.units['rmse_energy']
+        unit_force = self.units['rmse_force']
+        epochs = self.epochs
+
+        if len(force_train) != len(energy_train):
+            force_train = [np.nan for i in energy_train]
+            force_test = [np.nan for i in energy_test]
+
+        # Build the table header.
+        colhead_energy = 'RMSE(E) / ' + unit_energy
+        colhead_force = 'RMSE(F) / ' + unit_force
+        header = (f"Epoch | {colhead_energy:^18} | {colhead_force:^18} |")
+
+        # Build the table subheader.
+        subtraintest = f"{'Train':^8} | {'Test':^7}"
+        subheader = f"{'':5s} | {subtraintest} | {subtraintest} |"
+
+        # Print header, subheader, and their separator lines.
+        print(header)
+        print('=' * len(header))
+
+        print(subheader)
+        print('-' * len(subheader))
+
+        # Print the results of each epoch.
+        results = zip(epochs, energy_train, energy_test, force_train,
+                      force_test)
+        for epoch, e_train, e_test, f_train, f_test in results:
+            print(f'{epoch:5d} '
+                  + f'| {e_train:^9.4f}'
+                  + f'| {e_test:^8.4f}'
+                  + f'| {f_train:^9.4f}'
+                  + f'| {f_test:^8.4f}|',
+                  end='')
+
+            if epoch == self.opt_rmse_epoch:
+                print(' <-- Best Epoch')
+            else:
+                print('')
+
+    @property
+    def plot(self) -> RunnerFitResultsPlots:
+        """Create a plotting interface."""
+        return RunnerFitResultsPlots(self.epochs, self.rmse_energy,
+                                     self.rmse_forces, self.rmse_charge,
+                                     self.opt_rmse_epoch, self.units)
+
 
 class RunnerSplitTrainTest:
     """Storage container for the split between train and test set in RuNNer.
@@ -723,6 +800,10 @@ class RunnerSplitTrainTest:
                 elif split_type == 'testing':
                     self.test.append(point_idx)
 
+    @property
+    def plot(self) -> RunnerSplitTrainTestPlots:
+        """Create a plotting interface."""
+        return RunnerSplitTrainTestPlots(self.train, self.test)
 
 # Originally inherited from TypedDict, but this was removed for now to retain
 # backwards compatibility with Python 3.6 and 3.7.
