@@ -23,9 +23,11 @@ import numpy as np
 
 from ase.geometry import get_distances
 from ase.atoms import Atoms
+from ase.units import Bohr
 
 from runnerase.utils import get_elements
 
+from runnerase.plot import SymmetryFunctionSetPlots
 
 # Custom type specification for lists of symmetry function parameters. Can be
 # two kinds of tuples, depending on whether it is a radial or an angular
@@ -347,7 +349,7 @@ class SymmetryFunctionSet:
     def cutoffs(self) -> Optional[List[Optional[float]]]:
         """Show a list of all cutoffs in self.symmetryfunctions."""
         # Collect the cutoff values of all symmetryfunctions.
-        cutoffs = list(set(sf.cutoff for sf in self.symmetryfunctions))
+        cutoffs = list(set(sf.cutoff for sf in self.storage))
 
         # If the list is empty, return None instead.
         if len(cutoffs) == 0:
@@ -370,6 +372,16 @@ class SymmetryFunctionSet:
             raise Exception(f'{self.__class__.__name__} can only store data of'
                             + 'type SymmetryFunctionSet or SymmetryFunction.')
 
+    def reset(self):
+        """Clear all symmetryfunctions and sets from storage."""
+        self._sets: List[SymmetryFunctionSet] = []
+        self._symmetryfunctions: List[SymmetryFunction] = []
+
+    @property
+    def plot(self) -> SymmetryFunctionSetPlots:
+        """Create a plotting interface."""
+        return SymmetryFunctionSetPlots(self.storage)
+
 
 def get_element_groups(
     elements: List[str],
@@ -427,13 +439,16 @@ def get_minimum_distances(
     minimum_distances: Dict[str, float] = {}
     for elem1, elem2 in get_element_groups(elements, 2):
         for structure in dataset:
-
             elems = structure.get_chemical_symbols()
 
             # All positions of one element.
             pos1 = structure.positions[np.array(elems) == elem1]
             pos2 = structure.positions[np.array(elems) == elem2]
 
+            # If there is only one atom of this element, skip.
+            if pos1.shape[0] <= 1 or pos2.shape[0] <= 1:
+                continue
+
             distmatrix = get_distances(pos1, pos2)[1]
 
             # Remove same atom interaction.
@@ -557,7 +572,10 @@ def generate_symmetryfunctions_sftype2(
 
     # For radial symmetry functions, minimum element distances are required.
     if min_distances is None:
-        min_distances = get_minimum_distances(dataset, elements)
+        min_distances_ang = get_minimum_distances(dataset, elements)
+        min_distances = {}
+        for element, dist in min_distances_ang.items():
+            min_distances[element] = dist / Bohr
 
     # Create one set of symmetry functions for each element pair.
     for element_group in get_element_groups(elements, 2):
